formats

package
v0.36.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 8, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CaseCamel

func CaseCamel(str string) string

CaseCamel transforms string to `camelCase`

func CaseKebab

func CaseKebab(str string) string

CaseKebab transforms string to `kebab-case`

func CasePascal

func CasePascal(str string) string

CasePascal transforms string to `PascalCase`

func CasePast

func CasePast(str string) string

CasePast transforms the last word in the input to past tense, preserving the original casing style. Examples: "OrderCancel" → "OrderCancelled", "order_cancel" → "order_cancelled", "orderCancel" → "orderCancelled", "cancel" → "cancelled".

func CaseSnake

func CaseSnake(str string) string

CaseSnake transforms string to `snake_case`

func IsWholeNumber

func IsWholeNumber(f float64) bool

IsWholeNumber reports whether f represents an integer value (no fractional part).

Types

This section is empty.

Jump to